Learn R Programming

kimod (version 1.0.0)

NCI60Selec: Microarray gene expression profiles of the NCI 60 cell lines from 4 different platforms.

Description

The 60 human tumour cell lines are derived from patients with leukaemia, melanoma, lung, colon, central nervous system, ovarian, renal, breast and prostate cancers. The cell line panel is widely used in anti-cancer drug screen. In this dataset, a subset of microarray gene expression of the NCI 60 cell lines from four different platforms are combined in a list.

Usage

data(NCI60Selec)

Arguments

Value

  • NCI60Select list of data.frame.

format

NCI60Selec This data is an list of length 4.

source

Cell Miner http://discover.nci.nih.gov/cellminer/.

References

Reinhold WC, Sunshine M, Liu H, Varma S, Kohn KW, Morris J, Doroshow J, Pommier Y CellMiner: A Web-Based Suite of Genomic and Pharmacologic Tools to Explore Transcript and Drug Patterns in the NCI-60 Cell Line Set. Cancer Research. 2012 Jul, 15;72(14):3499-511

Examples

Run this code
data(NCI60Selec)

Run the code above in your browser using DataLab