Learn R Programming

kimod (version 1.0.0)

winesassesors: Description of a set of wines by a group of expert assessors.

Description

Were selected twelve wines made from Sauvignon Blanc grapes coming from three wine regions (four wines from each region): New Zealand, France, and Canada and then were interviewed 10 expert assessors to evaluate these wines.

Usage

data(winesassesors)

Arguments

Value

  • List with 10 items (all data.frame) with 12 rows each (common elements in Statis Methods) and differents variables types.

encoding

UTF-8

format

winesassesors This data frame contains an list of length 10 with 12 rows each. There are 10 studies, the assessors.

source

Abdi, H., Williams, L.J., Valentin, D., & Bennani-Dosse, M. (2012). STATIS and DISTATIS: optimum multitable principal component analysis and three way metric multidimensional scaling. WIREs Comput Stat, 4, 124-167.

References

Abdi, H., Williams, L.J., Valentin, D., & Bennani-Dosse, M. (2012). STATIS and DISTATIS: optimum multitable principal component analysis and three way metric multidimensional scaling. WIREs Comput Stat, 4, 124-167.

Examples

Run this code
data(winesassesors)

Run the code above in your browser using DataLab