encoding
UTF-8format
winesassesors This data frame contains an list of length 10 with 12 rows each. There are 10 studies, the assessors.source
Abdi, H., Williams, L.J., Valentin, D., & Bennani-Dosse, M. (2012). STATIS and DISTATIS: optimum multitable principal component analysis and three way metric multidimensional scaling. WIREs Comput Stat, 4, 124-167.